@@ -3,6 +3,37 @@
 
 // ===[ PRIMITIVE SET ]=======================================================
 
+PrimitiveSet::PrimitiveSet (
+
+    Material& in_material, 
+    int in_type,
+    int in_nverticesperelement,
+    bool in_ignoreExtent,
+    bool in_bboxChange
+    ) :
+Shape(in_material, in_ignoreExtent, SHAPE, in_bboxChange)
+{
+  type                = in_type;
+  nverticesperelement = in_nverticesperelement;
+}
+
+void PrimitiveSet::initPrimitiveSet(
+    int in_nvertices, 
+    double* in_vertices
+) {
+  nvertices           = in_nvertices;
+  nprimitives         = in_nvertices / nverticesperelement;
+  vertexArray.alloc(nvertices);
+  hasmissing = false;
+  for(int i=0;i<nvertices;i++) {
+    vertexArray[i].x = (float) in_vertices[i*3+0];
+    vertexArray[i].y = (float) in_vertices[i*3+1];
+    vertexArray[i].z = (float) in_vertices[i*3+2];
+    boundingBox += vertexArray[i];
+    hasmissing |= vertexArray[i].missing();
+  }
+}
+
 PrimitiveSet::PrimitiveSet (
 
     Material& in_material, 
@@ -10,17 +41,17 @@ PrimitiveSet::PrimitiveSet (
     double* in_vertices, 
     int in_type, 
     int in_nverticesperelement,
-    int in_ignoreExtent
+    bool in_ignoreExtent,
+    bool in_bboxChange
 
 )
   :
-Shape(in_material, in_ignoreExtent, SHAPE)
+Shape(in_material, in_ignoreExtent, SHAPE, in_bboxChange)
 {
   type                = in_type;
   nverticesperelement = in_nverticesperelement;
   nvertices           = in_nvertices;
   nprimitives         = in_nvertices / nverticesperelement;
-
   material.colorPerVertex(true, nvertices);
 
   vertexArray.alloc(nvertices);
@@ -110,27 +141,29 @@ void PrimitiveSet::draw(RenderContext* renderContext)
   SAVEGLERROR;
 }
 
-// ---------------------------------------------------------------------------
-
-void PrimitiveSet::renderZSort(RenderContext* renderContext)
+int PrimitiveSet::getAttributeCount(AABox& bbox, AttribID attrib)
 {
-  // sort by z-depth
-  
-  std::multimap<float,int> distanceMap;
-  for (int index = 0 ; index < nprimitives ; ++index ) {
-    float distance = renderContext->getDistance( getCenter(index) );
-    distanceMap.insert( std::pair<const float,int>(-distance,index) );
+  switch (attrib) {
+    case VERTICES: return nvertices;
   }
+  return Shape::getAttributeCount(bbox, attrib);
+}
 
-  // render ordered
-
-  drawBegin(renderContext);
-  
-  for ( std::multimap<float,int>::iterator iter = distanceMap.begin(); iter != distanceMap.end() ; ++ iter ) {
-    drawElement( renderContext, iter->second );
-  }  
-  
-  drawEnd(renderContext);
+void PrimitiveSet::getAttribute(AABox& bbox, AttribID attrib, int first, int count, double* result)
+{
+  int n = getAttributeCount(bbox, attrib);
+  if (first + count < n) n = first + count;
+  if (first < n) {
+    if (attrib == VERTICES) {
+      while (first < n) {
+        *result++ = vertexArray[first].x;
+        *result++ = vertexArray[first].y;
+        *result++ = vertexArray[first].z;
+        first++;
+      }
+    } else
+      Shape::getAttribute(bbox, attrib, first, count, result);
+  }
 }
 
 // ===[ FACE SET ]============================================================
@@ -144,12 +177,13 @@ FaceSet::FaceSet(
   double* in_texcoords,
   int in_type, 
   int in_nverticesperelement,
-  int in_ignoreExtent,
+  bool in_ignoreExtent,
   int in_useNormals,
-  int in_useTexcoords
+  int in_useTexcoords,
+  bool in_bboxChange
 
 )
-: PrimitiveSet(in_material, in_nelements, in_vertex, in_type, in_nverticesperelement, in_ignoreExtent)
+: PrimitiveSet(in_material, in_nelements, in_vertex, in_type, in_nverticesperelement, in_ignoreExtent, in_bboxChange)
 {
   if (material.lit) {
     normalArray.alloc(nvertices);
@@ -182,6 +216,57 @@ FaceSet::FaceSet(
   }
 }
 
+FaceSet::FaceSet(Material& in_material, 
+    int in_type,
+    int in_nverticesperelement,
+    bool in_ignoreExtent,
+    bool in_bboxChange
+    ) :
+  PrimitiveSet(in_material, in_type, in_nverticesperelement, in_ignoreExtent,in_bboxChange)
+{ 
+}
+
+void FaceSet::initFaceSet(
+  int in_nelements, 
+  double* in_vertex, 
+  double* in_normals,
+  double* in_texcoords
+) {
+  initPrimitiveSet(in_nelements, in_vertex);
+  
+  bool useNormals = (in_normals) ? true : false;
+  bool useTexcoords = (in_texcoords) ? true : false;
+
+  if (material.lit) {
+    normalArray.alloc(nvertices);
+    if (useNormals) {
+      for(int i=0;i<nvertices;i++) {
+        normalArray[i].x = (float) in_normals[i*3+0];
+        normalArray[i].y = (float) in_normals[i*3+1];
+        normalArray[i].z = (float) in_normals[i*3+2];
+      }
+    } else {
+      for (int i=0;i<=nvertices-nverticesperelement;i+=nverticesperelement) 
+      {   
+        if (hasmissing && (vertexArray[i].missing() ||
+                           vertexArray[i+1].missing() ||
+                           vertexArray[i+2].missing()) )
+          normalArray[i] = Vertex(0.0, 0.0, 0.0);
+        else
+          normalArray[i] = vertexArray.getNormal(i,i+1,i+2);
+        for (int j=1;j<nverticesperelement;++j)    
+          normalArray[i+j] = normalArray[i];
+      }
+    }
+  }
+  if (useTexcoords) {
+    texCoordArray.alloc(nvertices);
+    for(int i=0;i<nvertices;i++) {
+      texCoordArray[i].s = (float) in_texcoords[i*2+0];
+      texCoordArray[i].t = (float) in_texcoords[i*2+1];      
+    }
+  }
+}
 
 // ---------------------------------------------------------------------------
 
@@ -206,3 +291,44 @@ void FaceSet::drawEnd(RenderContext* renderContext)
 
   PrimitiveSet::drawEnd(renderContext);
 }
+
+
+int FaceSet::getAttributeCount(AABox& bbox, AttribID attrib)
+{
+  switch (attrib) {
+    case NORMALS: if (material.lit)
+    		    return nvertices;
+    		  else
+    		    return 0;
+    case TEXCOORDS: return texCoordArray.size();
+  }
+  return PrimitiveSet::getAttributeCount(bbox, attrib);
+}
+
+void FaceSet::getAttribute(AABox& bbox, AttribID attrib, int first, int count, double* result)
+{
+  int n = getAttributeCount(bbox, attrib);
+  if (first + count < n) n = first + count;
+  if (first < n) {
+    switch (attrib) {
+      case NORMALS: {
+        while (first < n) {
+          *result++ = normalArray[first].x;
+          *result++ = normalArray[first].y;
+          *result++ = normalArray[first].z;
+          first++;
+        }
+        return;
+      }
+      case TEXCOORDS: {
+        while (first < n) {
+          *result++ = texCoordArray[first].s;
+	  *result++ = texCoordArray[first].t;
+	  first++;
+	}
+	return;
+      }
+    }
+    PrimitiveSet::getAttribute(bbox, attrib, first, count, result);
+  }
+}
